# SummarizeTS.R -- summarizes the subsetted time series from ITERATE
#
# Patrick T. Brandt
#
# 20081229 : Initial version
# 20090410 : Added code to generate the smoothed version of the time
#            series matrix.
# 20090921 : Revised to make figures in B and W

library(zoo)

# Load the relevant data file

# Object "x" is a list of the datasets; object "full.daily" is the zoo
# time index for all of the data.

load("TargetSorted.RData")

## # Function to process 1 dataset of a specific vtype
## fvtype <- function(x, type)
## {
##     if(x$vtype==type)
##         { if(is.null(x$data)==FALSE) return(x$data)
##       }

## }

## tmp <- lapply(x, fvtype, type="Other")

# Aggregate by victim type
Officials <- Military <- Business <- PrivParties <- Terrorists <- Other <- matrix(0, 14595, 4)

for(i in 1:length(x))
{
    if(x[[i]]$vtype=="Officials")
    {
        Officials <- Officials + merge(full.daily, x[[i]]$data, fill=0)
    }

    if(x[[i]]$vtype=="Military")
    {
        Military <- Military + merge(full.daily, x[[i]]$data, fill=0)
    }

    if(x[[i]]$vtype=="Business")
    {
        Business <- Business + merge(full.daily, x[[i]]$data, fill=0)
    }

    if(x[[i]]$vtype=="Private Parties")
    {
        PrivParties <- PrivParties + merge(full.daily, x[[i]]$data, fill=0)
    }

    if(x[[i]]$vtype=="Terrorists")
    {
        Terrorists <- Terrorists + merge(full.daily, x[[i]]$data, fill=0)
    }
    if(x[[i]]$vtype=="Other")
    {
        Other <- Other + merge(full.daily, x[[i]]$data, fill=0)
    }

}

# Note all of these datasets will be daily
Officials <- zoo(Officials, index(full.daily))
Military <- zoo(Military, index(full.daily))
Business <- zoo(Business, index(full.daily))
PrivParties <- zoo(PrivParties, index(full.daily))
Terrorists <- zoo(Terrorists, index(full.daily))
Other <- zoo(Other, index(full.daily))

# Now make the monthly and quarterly
Officials.m <- aggregate(Officials, as.yearmon, sum)
Military.m <- aggregate(Military, as.yearmon, sum)
Business.m <- aggregate(Business, as.yearmon, sum)
PrivParties.m <- aggregate(PrivParties, as.yearmon, sum)
Terrorists.m <- aggregate(Terrorists, as.yearmon, sum)
Other.m <- aggregate(Other, as.yearmon, sum)

Officials.q <- aggregate(Officials, as.yearqtr, sum)
Military.q <- aggregate(Military, as.yearqtr, sum)
Business.q <- aggregate(Business, as.yearqtr, sum)
PrivParties.q <- aggregate(PrivParties, as.yearqtr, sum)
Terrorists.q <- aggregate(Terrorists, as.yearqtr, sum)
Other.q <- aggregate(Other, as.yearqtr, sum)

# Now plot everything

pdf(file="BasicSeriesACFs.pdf", width=6.5, height=7)
par(omi=c(0,0.75,1,0))
plot(Officials.m, main="Officials, monthly", xlab="Date")
plot(Military.m, main="Military, monthly", xlab="Date")
plot(Business.m, main="Business, monthly", xlab="Date")
plot(PrivParties.m, main="Private parties, monthly", xlab="Date")
plot(Terrorists.m,, main="Terrorists, monthly", xlab="Date")
plot(Other.m, main="Other, monthly", xlab="Date")

plot(Officials.q, main="Officials, quarterly", xlab="Date")
plot(Military.q, main="Military, quarterly", xlab="Date")
plot(Business.q, main="Business, quarterly", xlab="Date")
plot(PrivParties.q, main="Private parties, quarterly", xlab="Date")
plot(Terrorists.q, main="Terrorists, quarterly", xlab="Date")
plot(Other.q, main="Other, quarterly", xlab="Date")

acf(Officials.m, ci.type="ma")
mtext("Officials, monthly", outer=T, line=6.7, cex=0.75)
acf(Military.m, ci.type="ma")
mtext("Military, monthly", outer=T, line=6.7, cex=0.75)
acf(Business.m, ci.type="ma")
mtext("Business, monthly", outer=T, line=6.7, cex=0.75)
acf(PrivParties.m, ci.type="ma")
mtext("Private parties, monthly", outer=T, line=6.7, cex=0.75)
acf(Terrorists.m, ci.type="ma")
mtext("Terrorists, monthly", outer=T, line=6.7, cex=0.75)
acf(Other.m, ci.type="ma")
mtext("Other, monthly", outer=T, line=6.7, cex=0.75)

acf(Officials.q, ci.type="ma")
mtext("Officials, quarterly", outer=T, line=6.7, cex=0.75)
acf(Military.q, ci.type="ma")
mtext("Military, quarterly", outer=T, line=6.7, cex=0.75)
acf(Business.q, ci.type="ma")
mtext("Business, quarterly", outer=T, line=6.7, cex=0.75)
acf(PrivParties.q, ci.type="ma")
mtext("Private parties, quarterly", outer=T, line=6.7, cex=0.75)
acf(Terrorists.q, ci.type="ma")
mtext("Terrorists, quarterly", outer=T, line=6.7, cex=0.75)
acf(Other.q, ci.type="ma")
mtext("Other, quarterly", outer=T, line=6.7, cex=0.75)

dev.off()


# Get the cummulative sums
pdf(file="cusums.pdf")

plot(cbind(cumsum(Officials$Events),
           cumsum(Military$Events),
           cumsum(Business$Events),
           cumsum(PrivParties$Events)),
           plot.type="s", lty=1:6, lwd=2,
           ylab="Cumulative Number of Events", xlab="Date")

legend(-150, 3250, c("Officials", "Military", "Business",
                     "Private Parties"), lty=1:4, lwd=2)

dev.off()

# Now plot out things separately
Off <- M <- B <- P <- T <- Oth <- zoo(, index(full.daily))

# Officials
Off.Aborted <- aggregate(cbind(Off, x[[1]]$data[,4],
                     x[[2]]$data[,4], fill=0), as.yearqtr, sum)
colnames(Off.Aborted) <- c("People", "Property")

Off.Stopped <- aggregate(cbind(Off, x[[3]]$data[,4],
                     x[[4]]$data[,4], x[[5]]$data[,4], fill=0), as.yearqtr, sum)
colnames(Off.Stopped) <- c("People", "Property", "Unknown")

Off.Completed <- aggregate(cbind(Off, x[[6]]$data[,4],
                     x[[7]]$data[,4], x[[8]]$data[,4], fill=0), as.yearqtr, sum)
colnames(Off.Completed) <- c("People", "Property", "Unknown")

Off.Total <- rowSums(Off.Aborted) + rowSums(Off.Stopped) + rowSums(Off.Completed)

# Military
M.Aborted <- aggregate(cbind(M, x[[9]]$data[,4],
                     x[[10]]$data[,4], x[[11]]$data[,4], fill=0), as.yearqtr, sum)
colnames(M.Aborted) <- c("People", "Property", "Unknown")

M.Stopped <- aggregate(cbind(M, x[[12]]$data[,4],
                     x[[13]]$data[,4], fill=0), as.yearqtr, sum)
colnames(M.Stopped) <- c("People", "Property")

M.Completed <- aggregate(cbind(M, x[[14]]$data[,4],
                     x[[15]]$data[,4], x[[16]]$data[,4], fill=0), as.yearqtr, sum)
colnames(M.Completed) <- c("People", "Property", "Unknown")

M.Total <- rowSums(M.Aborted) + rowSums(M.Stopped) + rowSums(M.Completed)

# Business
B.Aborted <- aggregate(cbind(B, x[[17]]$data[,4],
                   x[[18]]$data[,4], fill=0), as.yearqtr, sum)
colnames(B.Aborted) <- c("People", "Property")

B.Stopped <- aggregate(cbind(B, x[[19]]$data[,4],
                   x[[20]]$data[,4], fill=0), as.yearqtr, sum)
colnames(B.Stopped) <- c("People", "Property")

B.Completed <- aggregate(cbind(B, x[[21]]$data[,4],
                     x[[22]]$data[,4], x[[23]]$data[,4], fill=0), as.yearqtr, sum)
colnames(B.Completed) <- c("People", "Property", "Unknown")

B.Total <- rowSums(B.Aborted) + rowSums(B.Stopped) + rowSums(B.Completed)

# Private Parties
P.Aborted <- aggregate(cbind(P, x[[24]]$data[,4],
                   x[[25]]$data[,4], fill=0), as.yearqtr, sum)
colnames(P.Aborted) <- c("People", "Property")

P.Stopped <- aggregate(cbind(P, x[[26]]$data[,4],
                   x[[27]]$data[,4], x[[28]]$data[,4], fill=0), as.yearqtr, sum)
colnames(P.Stopped) <- c("People", "Property", "Unknown")

P.Completed <- aggregate(cbind(P, x[[29]]$data[,4],
                     x[[30]]$data[,4], x[[31]]$data[,4], fill=0), as.yearqtr, sum)
colnames(P.Completed) <- c("People", "Property", "Unknown")

P.Total <- rowSums(P.Aborted) + rowSums(P.Stopped) + rowSums(P.Completed)

# Terrorists
T.Aborted <- aggregate(cbind(T, x[[32]]$data[,4],
                   x[[33]]$data[,4], fill=0), as.yearqtr, sum)
colnames(T.Aborted) <- c("People", "Property")

T.Stopped <- aggregate(cbind(T, x[[34]]$data[,4],
                   x[[35]]$data[,4], fill=0), as.yearqtr, sum)
colnames(T.Stopped) <- c("People", "Property")

T.Completed <- aggregate(cbind(T, x[[36]]$data[,4],
                     x[[37]]$data[,4], fill=0), as.yearqtr, sum)
colnames(T.Completed) <- c("People", "Property")

T.Total <- rowSums(T.Aborted) + rowSums(T.Stopped) + rowSums(T.Completed)

# Other
Oth.Aborted <- aggregate(cbind(Oth, x[[38]]$data[,4],
                   x[[39]]$data[,4], x[[40]]$data[,4], fill=0), as.yearqtr, sum)
colnames(Oth.Aborted) <- c("People", "Property", "Unknown")

Oth.Stopped <- aggregate(cbind(Oth, x[[41]]$data[,4],
                   x[[42]]$data[,4], x[[43]]$data[,4], fill=0), as.yearqtr, sum)
colnames(Oth.Stopped) <- c("People", "Property", "Unknown")

Oth.Completed <- aggregate(cbind(Oth, x[[44]]$data[,4],
                     x[[45]]$data[,4], x[[46]]$data[,4], fill=0), as.yearqtr, sum)
colnames(Oth.Completed) <- c("People", "Property", "Unknown")

Oth.Total <- rowSums(Oth.Aborted) + rowSums(Oth.Stopped) + rowSums(Oth.Completed)

# Now plot all of these: first one is raw counts; second one is the
# percentages.
pdf(file="Quarterlybytargetsuccessvictim.pdf", width=6.5, height=9)

par(mfrow=c(6,3), mai=c(0.25, 0.55, 0.3, 0.05),
    omi=c(0.8, 0.4, 0.4, 0), cex.axis=0.9)
plot(Off.Aborted, col=1:ncol(Off.Aborted), plot.type="s",
     main="Aborted", ylab="Officials", xlab="")
plot(Off.Stopped, col=1:ncol(Off.Stopped), plot.type="s",
     main="Stopped", ylab="", xlab="")
plot(Off.Completed, col=1:ncol(Off.Completed), plot.type="s",
     main="Completed", ylab="", xlab="")

plot(M.Aborted, col=1:ncol(M.Aborted), plot.type="s", ylab="Military", xlab="")
plot(M.Stopped, col=1:ncol(M.Stopped), plot.type="s", ylab="", xlab="")
plot(M.Completed, col=1:ncol(M.Completed), plot.type="s", ylab="", xlab="")

plot(B.Aborted, col=1:ncol(B.Aborted), plot.type="s", ylab="Business", xlab="")
plot(B.Stopped, col=1:ncol(B.Stopped), plot.type="s", ylab="", xlab="")
plot(B.Completed, col=1:ncol(B.Completed), plot.type="s", ylab="", xlab="")

plot(P.Aborted, col=1:ncol(P.Aborted), plot.type="s", ylab="Private Parties", xlab="")
plot(P.Stopped, col=1:ncol(P.Stopped), plot.type="s", ylab="", xlab="")
plot(P.Completed, col=1:ncol(P.Completed), plot.type="s", ylab="", xlab="")

plot(T.Aborted, col=1:ncol(T.Aborted), plot.type="s", ylab="Terrorists", xlab="")
plot(T.Stopped, col=1:ncol(T.Stopped), plot.type="s", ylab="", xlab="")
plot(T.Completed, col=1:ncol(T.Completed), plot.type="s", ylab="", xlab="")

plot(Oth.Aborted, col=1:ncol(Oth.Aborted), plot.type="s", ylab="Other", xlab="")
plot(Oth.Stopped, col=1:ncol(Oth.Stopped), plot.type="s", ylab="",
     xlab="")
legend("bottom", legend = c("People", "Property", "Unknown"),
       fill=1:3, horiz=F, inset=-1.25, xpd=NA)
plot(Oth.Completed, col=1:ncol(Oth.Completed), plot.type="s", ylab="", xlab="")

# Now add outer labels and a legend.
mtext("Target Type", 2, outer=TRUE, line=0.5)
mtext("Logistical Success", 3, outer=TRUE, line=0)

dev.off()

# Function to compute the percentages and format them
makeper <- function(num,den)
{
    den <- ifelse(den==0, 1, den)
    tmp <- num/den

    return(100*tmp)
}


pdf(file="PercentQuarterlybytargetsuccessvictim.pdf", width=6.5, height=9)

par(mfrow=c(4,3), mai=c(0.25, 0.55, 0.3, 0.05),
    omi=c(0.8, 0.4, 0.4, 0), cex.axis=0.9)

plot(makeper(Off.Aborted, Off.Total), col=1:ncol(Off.Aborted), plot.type="s",
     main="Aborted", ylab="Officials", xlab="", ylim=c(0,100))
plot(makeper(Off.Stopped, Off.Total), col=1:ncol(Off.Stopped), plot.type="s",
     main="Stopped", ylab="", xlab="", ylim=c(0,100))
plot(makeper(Off.Completed, Off.Total), col=1:ncol(Off.Completed), plot.type="s",
     main="Completed", ylab="", xlab="", ylim=c(0,100))

plot(makeper(M.Aborted, M.Total), col=1:ncol(M.Aborted),
     plot.type="s", ylab="Military", xlab="", ylim=c(0,100))
plot(makeper(M.Stopped, M.Total), col=1:ncol(M.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))
plot(makeper(M.Completed, M.Total), col=1:ncol(M.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

plot(makeper(B.Aborted, B.Total), col=1:ncol(B.Aborted),
     plot.type="s", ylab="Business", xlab="", ylim=c(0,100))
plot(makeper(B.Stopped, B.Total), col=1:ncol(B.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))
plot(makeper(B.Completed, B.Total), col=1:ncol(B.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

plot(makeper(P.Aborted, P.Total), col=1:ncol(P.Aborted),
     plot.type="s", ylab="Private Parties", xlab="", ylim=c(0,100))
plot(makeper(P.Stopped, P.Total), col=1:ncol(P.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

legend("bottom", legend = c("People", "Property", "Unknown"),
       fill=1:3, horiz=F, inset=-0.65, xpd=NA)

plot(makeper(P.Completed, P.Total), col=1:ncol(P.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

# Now add outer labels and a legend.
mtext("Target Type", 2, outer=TRUE, line=0.5)
mtext("Logistical Success", 3, outer=TRUE, line=0)

dev.off()

# Function to make AND SMOOTH the percentages.
makepersmooth <- function(num,den)
{
    den <- ifelse(den==0, 1, den)
    tmp <- 100*num/den

    m <- ncol(tmp)
    out <- as.ts(tmp)

    for(i in 1:m)
    {
        out[,i] <- stl(out[,i], s.window="periodic", robust=TRUE)$time.series[,2]
    }

    return(out)
}


pdf(file="SmoothedPercentQuarterlybytargetsuccessvictim.pdf", width=6.5, height=9)

par(mfrow=c(4,3), mai=c(0.25, 0.55, 0.3, 0.05),
    omi=c(0.8, 0.4, 0.4, 0), cex.axis=0.9)

plot(makepersmooth(Off.Aborted, Off.Total), lty=1:ncol(Off.Aborted), plot.type="s",
     main="Aborted", ylab="Officials", xlab="", ylim=c(0,100))
plot(makepersmooth(Off.Stopped, Off.Total), lty=1:ncol(Off.Stopped), plot.type="s",
     main="Stopped", ylab="", xlab="", ylim=c(0,100))
plot(makepersmooth(Off.Completed, Off.Total), lty=1:ncol(Off.Completed), plot.type="s",
     main="Completed", ylab="", xlab="", ylim=c(0,100))

plot(makepersmooth(M.Aborted, M.Total), lty=1:ncol(M.Aborted),
     plot.type="s", ylab="Military", xlab="", ylim=c(0,100))
plot(makepersmooth(M.Stopped, M.Total), lty=1:ncol(M.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))
plot(makepersmooth(M.Completed, M.Total), lty=1:ncol(M.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

plot(makepersmooth(B.Aborted, B.Total), lty=1:ncol(B.Aborted),
     plot.type="s", ylab="Business", xlab="", ylim=c(0,100))
plot(makepersmooth(B.Stopped, B.Total), lty=1:ncol(B.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))
plot(makepersmooth(B.Completed, B.Total), lty=1:ncol(B.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

plot(makepersmooth(P.Aborted, P.Total), lty=1:ncol(P.Aborted),
     plot.type="s", ylab="Private Parties", xlab="", ylim=c(0,100))
plot(makepersmooth(P.Stopped, P.Total), lty=1:ncol(P.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

legend("bottom", legend = c("People", "Property", "Unknown"),
       lty=1:3, horiz=F, inset=-0.65, xpd=NA)

plot(makepersmooth(P.Completed, P.Total), lty=1:ncol(P.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

# Now add outer labels and a legend.
mtext("Target Type", 2, outer=TRUE, line=0.5)
mtext("Logistical Success", 3, outer=TRUE, line=0)

dev.off()


# Now do the same thing as the smoothed quarterly for the monthly data
# for comparison
Off <- M <- B <- P <- T <- Oth <- zoo(, index(full.daily))

# Officials
Off.Aborted <- aggregate(cbind(Off, x[[1]]$data[,4],
                     x[[2]]$data[,4], fill=0), as.yearmon, sum)
colnames(Off.Aborted) <- c("People", "Property")

Off.Stopped <- aggregate(cbind(Off, x[[3]]$data[,4],
                     x[[4]]$data[,4], x[[5]]$data[,4], fill=0), as.yearmon, sum)
colnames(Off.Stopped) <- c("People", "Property", "Unknown")

Off.Completed <- aggregate(cbind(Off, x[[6]]$data[,4],
                     x[[7]]$data[,4], x[[8]]$data[,4], fill=0), as.yearmon, sum)
colnames(Off.Completed) <- c("People", "Property", "Unknown")

Off.Total <- rowSums(Off.Aborted) + rowSums(Off.Stopped) + rowSums(Off.Completed)

# Military
M.Aborted <- aggregate(cbind(M, x[[9]]$data[,4],
                     x[[10]]$data[,4], x[[11]]$data[,4], fill=0), as.yearmon, sum)
colnames(M.Aborted) <- c("People", "Property", "Unknown")

M.Stopped <- aggregate(cbind(M, x[[12]]$data[,4],
                     x[[13]]$data[,4], fill=0), as.yearmon, sum)
colnames(M.Stopped) <- c("People", "Property")

M.Completed <- aggregate(cbind(M, x[[14]]$data[,4],
                     x[[15]]$data[,4], x[[16]]$data[,4], fill=0), as.yearmon, sum)
colnames(M.Completed) <- c("People", "Property", "Unknown")

M.Total <- rowSums(M.Aborted) + rowSums(M.Stopped) + rowSums(M.Completed)

# Business
B.Aborted <- aggregate(cbind(B, x[[17]]$data[,4],
                   x[[18]]$data[,4], fill=0), as.yearmon, sum)
colnames(B.Aborted) <- c("People", "Property")

B.Stopped <- aggregate(cbind(B, x[[19]]$data[,4],
                   x[[20]]$data[,4], fill=0), as.yearmon, sum)
colnames(B.Stopped) <- c("People", "Property")

B.Completed <- aggregate(cbind(B, x[[21]]$data[,4],
                     x[[22]]$data[,4], x[[23]]$data[,4], fill=0), as.yearmon, sum)
colnames(B.Completed) <- c("People", "Property", "Unknown")

B.Total <- rowSums(B.Aborted) + rowSums(B.Stopped) + rowSums(B.Completed)

# Private Parties
P.Aborted <- aggregate(cbind(P, x[[24]]$data[,4],
                   x[[25]]$data[,4], fill=0), as.yearmon, sum)
colnames(P.Aborted) <- c("People", "Property")

P.Stopped <- aggregate(cbind(P, x[[26]]$data[,4],
                   x[[27]]$data[,4], x[[28]]$data[,4], fill=0), as.yearmon, sum)
colnames(P.Stopped) <- c("People", "Property", "Unknown")

P.Completed <- aggregate(cbind(P, x[[29]]$data[,4],
                     x[[30]]$data[,4], x[[31]]$data[,4], fill=0), as.yearmon, sum)
colnames(P.Completed) <- c("People", "Property", "Unknown")

P.Total <- rowSums(P.Aborted) + rowSums(P.Stopped) + rowSums(P.Completed)


pdf(file="SmoothedPercentMonthlybytargetsuccessvictim.pdf", width=6.5, height=9)

par(mfrow=c(4,3), mai=c(0.25, 0.55, 0.3, 0.05),
    omi=c(0.8, 0.4, 0.4, 0), cex.axis=0.9)

plot(makepersmooth(Off.Aborted, Off.Total), lty=1:ncol(Off.Aborted), plot.type="s",
     main="Aborted", ylab="Officials", xlab="", ylim=c(0,100))
plot(makepersmooth(Off.Stopped, Off.Total), lty=1:ncol(Off.Stopped), plot.type="s",
     main="Stopped", ylab="", xlab="", ylim=c(0,100))
plot(makepersmooth(Off.Completed, Off.Total), lty=1:ncol(Off.Completed), plot.type="s",
     main="Completed", ylab="", xlab="", ylim=c(0,100))

plot(makepersmooth(M.Aborted, M.Total), lty=1:ncol(M.Aborted),
     plot.type="s", ylab="Military", xlab="", ylim=c(0,100))
plot(makepersmooth(M.Stopped, M.Total), lty=1:ncol(M.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))
plot(makepersmooth(M.Completed, M.Total), lty=1:ncol(M.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

plot(makepersmooth(B.Aborted, B.Total), lty=1:ncol(B.Aborted),
     plot.type="s", ylab="Business", xlab="", ylim=c(0,100))
plot(makepersmooth(B.Stopped, B.Total), lty=1:ncol(B.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))
plot(makepersmooth(B.Completed, B.Total), lty=1:ncol(B.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

plot(makepersmooth(P.Aborted, P.Total), lty=1:ncol(P.Aborted),
     plot.type="s", ylab="Private Parties", xlab="", ylim=c(0,100))
plot(makepersmooth(P.Stopped, P.Total), lty=1:ncol(P.Stopped),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

legend("bottom", legend = c("People", "Property", "Unknown"),
       lty=1:3, horiz=F, inset=-0.65, xpd=NA)

plot(makepersmooth(P.Completed, P.Total), lty=1:ncol(P.Completed),
     plot.type="s", ylab="", xlab="", ylim=c(0,100))

# Now add outer labels and a legend.
mtext("Target Type", 2, outer=TRUE, line=0.5)
mtext("Logistical Success", 3, outer=TRUE, line=0)

dev.off()

# Save the results

save(Officials, Military, Business, PrivParties,
     Terrorists, Other, file="TargetDaily.RData")

save(Officials.m, Military.m, Business.m, PrivParties.m, Terrorists.m,
     Other.m, file="TargetMonthly.RData")

save(Officials.q, Military.q, Business.q, PrivParties.q, Terrorists.q,
     Other.q, file="TargetQuarterly.RData")

q(save="no")

